/* capture.c (c) 2004 Petr Danecek
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __CAPTURE_H__
#define __CAPTURE_H__

#define MAX_CMD_LEN 255	
#define USLEEP 50000

#include <usb.h>
#include <libptp2/ptp.h>

typedef struct
{
      usb_dev_handle* handle;
      int inep;
      int outep;
      int intep;
}
PTP_USB;


/*
 * the 'settings' struct
 */
typedef struct
{
#ifdef HAVE_GTK
      int viewfinder;
      int gtk;
      int alignview;
      int bordersview;
      int viewfinder_opacity;
      int viewfinderwait;  /* bool to suspend viewfinder refresh while capturing */
      char *alignfname;
      char *tmpalign;
      char *vfsave_file;
      int   vfsave_idx;
#endif
      struct usb_device *dev;
      PTPParams params;
      PTP_USB ptp_usb;
}
settings_t;

void run_server(void);
int run_client(int argc, char *argv[]);
void help(char *cmd);
int exec_cmd(char *cmd);
int cmdcmp(char *cmd1, char *cmd2); /* like string compare funcs: 0 if they are the same */
void server_exit_nicely();
char *getarg(char *line, int *n);

void msg_cmd_ok(char *cmd);
void msg_cmd_info(char *cmd, const char *format, ...);
void msg_cmd_error(char *cmd, const char *format, ...);
int msg_send(const char *format, ...);
int msg_get(char *str, int maxlen);
void debug(const char *format, ...);
void error(const char *format, ...);

#include "properties.h"

/* 
 * the communication protocol is simple:
 * 1. client: send_msg("command [parameters]")
 * 2. server: 
 *  a) send_msg("command ok") 
 *  b) send_msg("command error[: msg]")
 *  c) send_msg("command info: msg")
 */
struct _cmd_t
{
      char *command;
      int ptpcode;
      int (*handler)(struct _cmd_t *, char *);   /* the return value: 0 ok, 1=break session */
      allowed_t *params;
      char *help;
};

typedef struct _cmd_t cmd_t;

#include <stdio.h>
extern char *SOCK_PATH;
extern FILE *log_file;
extern int DEBUG;
extern int SOCKET;
extern cmd_t cmds[];
extern settings_t settings;

#ifdef HAVE_GTK
#include <gtk/gtk.h>
void viewfinder_on(settings_t *settings);
void viewfinder_off(settings_t *settings);
#endif

/* return value of the handlers:
 *    0 = default
 *    1 = quit the connection (leave_handler)
 */
int quit_handler(cmd_t *, char *args);		
int status_handler(cmd_t *, char *args);
int start_handler(cmd_t *, char *args);
int leave_handler(cmd_t *, char *args);
int debug_handler(cmd_t *, char *args);
int capture_handler(cmd_t *, char *args);
int photograph_handler(cmd_t *, char *args);
int viewfinder_handler(cmd_t *, char *args);
int vfalign_handler(cmd_t *, char *args);
int vftrans_handler(cmd_t *, char *args);
int borders_handler(cmd_t *, char *args);
int focuslock_handler(cmd_t *, char *args);
int prop8_handler(cmd_t *, char *args);
int prop16_handler(cmd_t *, char *args);
int test_handler(cmd_t *, char *args);
int vfsave_handler(cmd_t *,char *args);



#define CMD_START "start"
#define CMD_QUIT "quit"
#define CMD_STATUS "status"
#define CMD_UNKNOWN "Unknown command"
#define CMD_LEAVE "detach"
#define CMD_DEBUG "debug"
#define CMD_HELP "help"
#define CMD_ZOOM "zoom"
#define CMD_FLASH "flash"
#define CMD_CAPTURE "capture"
#define CMD_PHOTOGRAPH "photograph"
#define CMD_MACRO "macro"
#define CMD_APERTURE "aperture"
#define CMD_SHUTTER "shutter"
#define CMD_VF "viewfinder"
#define CMD_SETVFOUTPUT "setvfout"
#define CMD_VFSAVE "vfsave"
#define CMD_VFALIGN "vfalign"
#define CMD_VFTRANS "vftrans"
#define CMD_BORDERS "borders"
#define CMD_TVAV "tv/av"
#define CMD_FP "focuspoint"
#define CMD_FOCUS_LOCK "focus"
#define CMD_EXPCOMP "ecomp"
#define CMD_ISO_SPEED "iso"
#define CMD_WHITE_BAL "white"
#define CMD_PHOTO_EFFECT "effect"
#define CMD_LIGHT_METER "metering"
#define CMD_TEST "test"
#define CMD_QUAL "qual"
#define CMD_SIZE "size"
#define CMD_D045 "d045"   /*XXX ??! */

#endif

