/* capture.c (c) 2004 Petr Danecek
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <string.h>
#include "properties.h"
#include "capture.h"

allowed_t debug_vals[] =
{
	{ 0, "off" },
	{ 1, "on" },
	{ 0, NULL },
};


#ifdef HAVE_GTK

allowed_t vfout_vals[]=
{
      { 1, "lcd"},
      { 2, "video"},
      { 3, "off"},
};

allowed_t vfalign_vals[] = 
{
      { 0, "off"},
      { 1, "quarters" },
      { 2, "hstripes" },
      { 3, "vstripes" },
      { 4, "squares" },
      { 5, "pseudo-transparent" },
      { 6, "transparent" },
      { 0, NULL},
};


allowed_t vftrans_vals[] = 
{
      { 10, "10%" },
      { 20, "20%" },
      { 30, "30%" },
      { 40, "40%" },
      { 50, "50%" },
      { 60, "60%" },
      { 70, "70%" },
      { 80, "80%" },
      { 90, "90%" },
      { 0, NULL},
};


allowed_t borders_vals[] =
{
      { 0, "0" },
      { 5, "5" },
      { 10, "10" },
      { 15, "15" },
      { 20, "20" },
      { 25, "25" },
      { 30, "30" },
      { 35, "35" },
      { 40, "40" },
      { 45, "45" },
      { 50, "50" },
      {0, NULL },
};

#endif

allowed_t exposure_compensation_vals[] =
{
      { 0xff, "factory default" },
      { 8 , "+2" },
      { 11, "+1 2/3" },
      { 13, "+1 1/3" },
      { 16, "+1" },
      { 19, "+2/3" },
      { 21, "+1/3" },
      { 24,  "0" },
      { 27, "-1/3" },
      { 29, "-2/3" },
      { 32, "-1" },
      { 35, "-1 1/3" },
      { 37, "-1 2/3" },
      { 40, "-2" },
      { 0 , NULL },
};

allowed_t iso_speed_vals[] =
{
      { 0xffff, "factory default"  },
      { 0x0040, "50" },
      { 0x0048, "100" },
      { 0x0050, "200" },
      { 0x0058, "400" },
      { 0x0000, "Auto" },
      { 0, NULL }
};


allowed_t white_balance_vals[] =
{
      { 0, "Auto" },
      { 1, "Daylight" },
      { 2, "Cloudy" },
      { 3, "Tungsten" },
      { 4, "Fluorescent" },
      { 7, "Fluorescent H" },
      { 6, "Custom" },
      { 0, NULL },
};

allowed_t photo_effect_vals[] =
{
      { 0, "off" },
      { 1, "Vivid" },
      { 2, "Neutral" },
      { 3, "Low sharpening" },
      { 4, "Sepia" },
      { 5, "Black & white" },
      { 0, NULL },
};

allowed_t light_metering_vals[] =
{
      { 0, "center weighted(?)" },
      { 1, "spot" },
      { 3, "integral(?)" },
      { 0, NULL },
};

allowed_t zoom_vals[] = 
{
      { 0, "0"},
      { 1, "1"},
      { 2, "2"},
      { 3, "3"},
      { 4, "4"},
      { 5, "5"},
      { 6, "6"},
      { 7, "7"},
      { 8, "8"},
      { 9, "9"},
      { 10, "10"},
      { 11, "11"},
      { 12, "12"},
      { 13, "13"},
      { 14, "14"},
      { 15, "15"},
      { 0, NULL},
};

allowed_t focus_vals[] =
{
      { 0, "unlock" },
      { 1, "lock" },
      { 0, NULL },
};

allowed_t flash_vals[] =
{     
      { 0, "off" },
      { 1, "auto" },
      { 2, "on" },
      { 5, "auto red eye" },
      { 6, "on red eye" },
      { 0, NULL },
};

allowed_t vf_vals[] =
{
      { 0, "off" },
      { 1, "on" },
      { 2, "refresh" },
      {0, NULL },
};

allowed_t tvav_vals[] =
{
      { 1, "program" },
      { 2, "shutter priority" },
      { 3, "aperture priority" },
      { 4, "manual" },
      { 0 , NULL},
};

allowed_t focuspoint_vals[] =
{
      { 0x3003, "center" },
      { 0x3001, "auto" },
      { 0, NULL},
};

allowed_t macro_vals[] =
{
      { 1, "off" },
      { 3, "on" },
      {0, NULL },
};


allowed_t shutter_vals[] =
{
      { 0     , "auto" },
      { 0x0018, "15\"" },
      { 0x001b, "13\"" },
      { 0x001d, "10\"" },
      { 0x0020, "8\"" },
      { 0x0023, "6\"" },
      { 0x0025, "5\"" },
      { 0x0028, "4\"" },
      { 0x002b, "3\"2" },
      { 0x002d, "2\"5" },
      { 0x0030, "2\"" },
      { 0x0033, "1\"6" },
      { 0x0035, "1\"3" },
      { 0x0038, "1\"" },
      { 0x003b, "0\"8" },
      { 0x003d, "0\"6" },
      { 0x0040, "0\"5" },
      { 0x0043, "0\"4" },
      { 0x0045, "0\"3" },
      { 0x0048, "1/4" },
      { 0x004b, "1/5" },
      { 0x004d, "1/6" },
      { 0x0050, "1/8" },
      { 0x0053, "1/10" },
      { 0x0055, "1/13" },
      { 0x0058, "1/15" },
      { 0x005b, "1/20" },
      { 0x005d, "1/25" },
      { 0x0060, "1/30" },
      { 0x0063, "1/40" },
      { 0x0065, "1/50" },
      { 0x0068, "1/60" },
      { 0x006b, "1/80" },
      { 0x006d, "1/100" },
      { 0x0070, "1/125" },
      { 0x0073, "1/160" },
      { 0x0075, "1/200" },
      { 0x0078, "1/250" },
      { 0x007b, "1/320" },
      { 0x007d, "1/400" },
      { 0x0080, "1/500" },
      { 0x0083, "1/640" },
      { 0x0085, "1/800" },
      { 0x0088, "1/1000" },
      { 0x008b, "1/1250" },
      { 0x008d, "1/1600" },
      { 0x0090, "1/2000" },
      { 0, NULL },
};

allowed_t aperture_vals[] =
{
      { 0xffff, "auto" },
      { 0x0018, "2.0" },    /* Added on request for G5 */
      { 0x001B, "2.2" },    /* Added on request for G5 */
      { 0x001D, "2.5" },    /* Added on request for G5 */
      { 0x0020, "2.8" },
      { 0x0023, "3.2" },
      { 0x0025, "3.5" },
      { 0x0028, "4.0" },
      { 0x002b, "4.5" },
      { 0x0030, "5.6" },
      { 0x0033, "6.3" },
      { 0x0035, "7.1" },
      { 0x0038, "8.0" },
      { 0x002d, "5" },
      { 0 , NULL},
};


/* added by wacky */
allowed_t d045_vals[] =
{
      { 0x0001, "1" },
      { 0x0002, "2" },
      { 0x0003, "3" },
      { 0x0004, "4" },
      { 0x0005, "5" },
      { 0x0006, "6" },
      { 0x0007, "7" },
      { 0 , NULL},
};


allowed_t qual_vals[] =
{
      { 5, "superfine" },
      { 3, "fine" },
      { 2, "normal" },
      { 0 , NULL},
};

allowed_t size_vals[] =
{
      { 0, "large" },
      { 1, "medium1" },
      { 3, "medium2" },
      { 7, "medium3" },
      { 2, "small" },
      { 0 , NULL},
};

int value1_ok(allowed_t *all, char *value, int *len)
{
      int n;

      value = getarg(value, &n);
      if ( ! value ) return -1;

      *len = n;
      
      while ( all && all->string )
      {
	    if ( ! strncasecmp(value, all->string, n) ) 
		  return all->code;

	    all++;
      }

      return -1;
}


int value_ok(allowed_t *all, char *value)
{
      int n;

      value = getarg(value, &n);

      if ( ! value ) return -1;

      while ( all && all->string )
      {
	    if ( ! strcasecmp(value, all->string) ) 
		  return all->code;

	    all++;
      }

      return -1;
}

char *get_name_from_code(allowed_t *all, int code)
{
      while ( all && all->string )
      {
	    if (all->code == code)
               return all->string;

	    all++;
      }
      return "Unknown";
}


allowed_t *get_allowed_values(char *arg)
{
      int n;
      cmd_t *c;

      arg = getarg(arg, &n);
      if ( ! arg ) { return NULL; }

      c = cmds;
      while ( c->command )
      {
	    if ( ! cmdcmp(arg, c->command) ) 
	    {
		  if ( c->params)
			return c->params;
		  else
			return NULL;
	    }
	    c++;
      }

      return NULL;
}


